@@ -16,7 +16,7 @@ use Cwd;
 ######################################################################
 #### Configuration Section
 
-$VERSION = '3.476';
+$VERSION = '3.478';
 
 # Basenames we should ignore when recursing directories,
 # Because they contain large files of no relevance
@@ -386,12 +386,13 @@ sub file_substitute {
     my $self = shift;
     my $filename = shift;
     my $out = $filename;
-    while ($filename =~ /\$([A-Za-z_0-9]+)\b/g
-           || $filename =~ /\$\{[A-Za-z_0-9]+\}\b/g) {
+    while ($filename =~ /\$([A-Za-z_0-9]+)\b/g) {
 	my $var = $1;
-	if (defined $ENV{$var}) {
-	    $out =~ s/\$$var\b/$ENV{$var}/g;
-	}
+	$out =~ s/\$$var\b/$ENV{$var}/g if defined $ENV{$var};
+    }
+    while ($filename =~ /\$\{([A-Za-z_0-9]+)\}/g) {
+	my $var = $1;
+	$out =~ s/\$\{$var\}/$ENV{$var}/g if defined $ENV{$var};
     }
     $out =~ s!^~!$ENV{HOME}/!;
     return $out;
